# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/dataservice.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from . import dataservice_messages_pb2 as protos_dot_dataservice__messages__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18protos/dataservice.proto\x12\x12protos.dataservice\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a!protos/dataservice_messages.proto\x1a\x1cprotos/common_messages.proto\"@\n\x15MakePersistentRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x13\n\x0bpickled_obj\x18\x02 \x03(\x0c\"s\n\x17\x43\x61llActiveMethodRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tobject_id\x18\x02 \x01(\t\x12\x13\n\x0bmethod_name\x18\x03 \x01(\t\x12\x0c\n\x04\x61rgs\x18\x04 \x01(\x0c\x12\x0e\n\x06kwargs\x18\x05 \x01(\x0c\x32\x99%\n\x0b\x44\x61taService\x12Y\n\rinitBackendID\x12(.protos.dataservice.InitBackendIDRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12y\n\x1d\x61ssociateExecutionEnvironment\x12\x38.protos.dataservice.AssociateExecutionEnvironmentRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x61\n\x11\x64\x65ployMetaClasses\x12,.protos.dataservice.DeployMetaClassesRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12Y\n\rdeployClasses\x12(.protos.dataservice.DeployClassesRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12U\n\x0b\x65nrichClass\x12&.protos.dataservice.EnrichClassRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12~\n\x15newPersistentInstance\x12\x30.protos.dataservice.NewPersistentInstanceRequest\x1a\x31.protos.dataservice.NewPersistentInstanceResponse\"\x00\x12W\n\x0cstoreObjects\x12\'.protos.dataservice.StoreObjectsRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12l\n\x0fgetCopyOfObject\x12*.protos.dataservice.GetCopyOfObjectRequest\x1a+.protos.dataservice.GetCopyOfObjectResponse\"\x00\x12W\n\x0cupdateObject\x12\'.protos.dataservice.UpdateObjectRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\ngetObjects\x12%.protos.dataservice.GetObjectsRequest\x1a&.protos.dataservice.GetObjectsResponse\"\x00\x12]\n\nnewVersion\x12%.protos.dataservice.NewVersionRequest\x1a&.protos.dataservice.NewVersionResponse\"\x00\x12\x63\n\x12\x63onsolidateVersion\x12-.protos.dataservice.ConsolidateVersionRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12Y\n\rupsertObjects\x12(.protos.dataservice.UpsertObjectsRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\nnewReplica\x12%.protos.dataservice.NewReplicaRequest\x1a&.protos.dataservice.NewReplicaResponse\"\x00\x12`\n\x0bmoveObjects\x12&.protos.dataservice.MoveObjectsRequest\x1a\'.protos.dataservice.MoveObjectsResponse\"\x00\x12\x66\n\rremoveObjects\x12(.protos.dataservice.RemoveObjectsRequest\x1a).protos.dataservice.RemoveObjectsResponse\"\x00\x12s\n\x18migrateObjectsToBackends\x12).protos.dataservice.MigrateObjectsRequest\x1a*.protos.dataservice.MigrateObjectsResponse\"\x00\x12\x93\x01\n\x1cgetClassIDFromObjectInMemory\x12\x37.protos.dataservice.GetClassIDFromObjectInMemoryRequest\x1a\x38.protos.dataservice.GetClassIDFromObjectInMemoryResponse\"\x00\x12~\n\x15\x65xecuteImplementation\x12\x30.protos.dataservice.ExecuteImplementationRequest\x1a\x31.protos.dataservice.ExecuteImplementationResponse\"\x00\x12^\n\x0emakePersistent\x12,.protos.dataservice.OldMakePersistentRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12O\n\x08\x66\x65\x64\x65rate\x12#.protos.dataservice.FederateRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12S\n\nunfederate\x12%.protos.dataservice.UnfederateRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12_\n\x10notifyFederation\x12+.protos.dataservice.NotifyFederationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12\x63\n\x12notifyUnfederation\x12-.protos.dataservice.NotifyUnfederationRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12Q\n\x06\x65xists\x12!.protos.dataservice.ExistsRequest\x1a\".protos.dataservice.ExistsResponse\"\x00\x12U\n\x0bsynchronize\x12&.protos.dataservice.SynchronizeRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12Q\n\tstoreToDB\x12$.protos.dataservice.StoreToDBRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12Z\n\tgetFromDB\x12$.protos.dataservice.GetFromDBRequest\x1a%.protos.dataservice.GetFromDBResponse\"\x00\x12S\n\nupdateToDB\x12%.protos.dataservice.UpdateToDBRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12S\n\ndeleteToDB\x12%.protos.dataservice.DeleteToDBRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\x0f\x64\x65leteSetFromDB\x12*.protos.dataservice.DeleteSetFromDBRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\nexistsInDB\x12%.protos.dataservice.ExistsInDBRequest\x1a&.protos.dataservice.ExistsInDBResponse\"\x00\x12[\n\x1c\x63leanExecutionClassDirectory\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12M\n\x0e\x63loseDbHandler\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12G\n\x08shutDown\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12S\n\x14\x64isconnectFromOthers\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12U\n\x16registerPendingObjects\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12J\n\x0b\x63leanCaches\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12]\n\x0f\x61\x63tivateTracing\x12*.protos.dataservice.ActivateTracingRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12P\n\x11\x64\x65\x61\x63tivateTracing\x12\x1b.protos.common.EmptyMessage\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12L\n\tgetTraces\x12\x1b.protos.common.EmptyMessage\x1a .protos.common.GetTracesResponse\"\x00\x12U\n\x0b\x64\x65leteAlias\x12&.protos.dataservice.DeleteAliasRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12m\n\x17\x64\x65tachObjectFromSession\x12\x32.protos.dataservice.DetachObjectFromSessionRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12_\n\x10\x63loseSessionInDS\x12+.protos.dataservice.CloseSessionInDSRequest\x1a\x1c.protos.common.ExceptionInfo\"\x00\x12i\n\x15getRetainedReferences\x12\x1b.protos.common.EmptyMessage\x1a\x31.protos.dataservice.GetRetainedReferencesResponse\"\x00\x12T\n\rgetNumObjects\x12\x1b.protos.common.EmptyMessage\x1a$.protos.common.GetNumObjectsResponse\"\x00\x12X\n\x11getNumObjectsInEE\x12\x1b.protos.common.EmptyMessage\x1a$.protos.common.GetNumObjectsResponse\"\x00\x12[\n\x0egetObjectGraph\x12\x1b.protos.common.EmptyMessage\x1a*.protos.dataservice.GetObjectGraphResponse\"\x00\x12U\n\x0eMakePersistent\x12).protos.dataservice.MakePersistentRequest\x1a\x16.google.protobuf.Empty\"\x00\x12^\n\x10\x43\x61llActiveMethod\x12+.protos.dataservice.CallActiveMethodRequest\x1a\x1b.google.protobuf.BytesValue\"\x00\x42R\n8es.bsc.dataclay.communication.grpc.generated.dataserviceB\x16\x44\x61taServiceGrpcServiceb\x06proto3')



_MAKEPERSISTENTREQUEST = DESCRIPTOR.message_types_by_name['MakePersistentRequest']
_CALLACTIVEMETHODREQUEST = DESCRIPTOR.message_types_by_name['CallActiveMethodRequest']
MakePersistentRequest = _reflection.GeneratedProtocolMessageType('MakePersistentRequest', (_message.Message,), {
  'DESCRIPTOR' : _MAKEPERSISTENTREQUEST,
  '__module__' : 'protos.dataservice_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.MakePersistentRequest)
  })
_sym_db.RegisterMessage(MakePersistentRequest)

CallActiveMethodRequest = _reflection.GeneratedProtocolMessageType('CallActiveMethodRequest', (_message.Message,), {
  'DESCRIPTOR' : _CALLACTIVEMETHODREQUEST,
  '__module__' : 'protos.dataservice_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.CallActiveMethodRequest)
  })
_sym_db.RegisterMessage(CallActiveMethodRequest)

_DATASERVICE = DESCRIPTOR.services_by_name['DataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n8es.bsc.dataclay.communication.grpc.generated.dataserviceB\026DataServiceGrpcService'
  _MAKEPERSISTENTREQUEST._serialized_start=174
  _MAKEPERSISTENTREQUEST._serialized_end=238
  _CALLACTIVEMETHODREQUEST._serialized_start=240
  _CALLACTIVEMETHODREQUEST._serialized_end=355
  _DATASERVICE._serialized_start=358
  _DATASERVICE._serialized_end=5119
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/common_messages.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cprotos/common_messages.proto\x12\rprotos.common\"\x1e\n\nCredential\x12\x10\n\x08password\x18\x01 \x01(\t\":\n\rParamOrReturn\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x17\n\x0fserializedParam\x18\x02 \x01(\x0c\"\x0e\n\x0c\x45mptyMessage\"\xeb\x05\n\x1cSerializedParametersOrReturn\x12\x11\n\tnumParams\x18\x01 \x01(\x05\x12M\n\timmParams\x18\x02 \x03(\x0b\x32:.protos.common.SerializedParametersOrReturn.ImmParamsEntry\x12O\n\nlangParams\x18\x03 \x03(\x0b\x32;.protos.common.SerializedParametersOrReturn.LangParamsEntry\x12W\n\x0evolatileParams\x18\x04 \x03(\x0b\x32?.protos.common.SerializedParametersOrReturn.VolatileParamsEntry\x12O\n\npersParams\x18\x05 \x03(\x0b\x32;.protos.common.SerializedParametersOrReturn.PersParamsEntry\x1aW\n\x0eImmParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.protos.common.ImmutableParamOrReturn:\x02\x38\x01\x1aW\n\x0fLangParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x33\n\x05value\x18\x02 \x01(\x0b\x32$.protos.common.LanguageParamOrReturn:\x02\x38\x01\x1a\x61\n\x13VolatileParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x39\n\x05value\x18\x02 \x01(\x0b\x32*.protos.common.ObjectWithDataParamOrReturn:\x02\x38\x01\x1aY\n\x0fPersParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x35\n\x05value\x18\x02 \x01(\x0b\x32&.protos.common.PersistentParamOrReturn:\x02\x38\x01\"*\n\x16ImmutableParamOrReturn\x12\x10\n\x08objbytes\x18\x01 \x01(\x0c\"\\\n\x17PersistentParamOrReturn\x12\x0b\n\x03oid\x18\x01 \x01(\t\x12\x0c\n\x04hint\x18\x02 \x01(\t\x12\x0f\n\x07\x63lassID\x18\x03 \x01(\t\x12\x15\n\rextDataClayID\x18\x04 \x01(\t\"\x86\x01\n\x1bObjectWithDataParamOrReturn\x12\x0b\n\x03oid\x18\x01 \x01(\t\x12\x0f\n\x07\x63lassid\x18\x02 \x01(\t\x12\x37\n\x08metadata\x18\x03 \x01(\x0b\x32%.protos.common.DataClayObjectMetaData\x12\x10\n\x08objbytes\x18\x04 \x01(\x0c\"b\n\x15LanguageParamOrReturn\x12\x37\n\x08metadata\x18\x01 \x01(\x0b\x32%.protos.common.DataClayObjectMetaData\x12\x10\n\x08objbytes\x18\x02 \x01(\x0c\"\x93\x04\n\x16\x44\x61taClayObjectMetaData\x12=\n\x04oids\x18\x01 \x03(\x0b\x32/.protos.common.DataClayObjectMetaData.OidsEntry\x12\x45\n\x08\x63lassids\x18\x02 \x03(\x0b\x32\x33.protos.common.DataClayObjectMetaData.ClassidsEntry\x12?\n\x05hints\x18\x03 \x03(\x0b\x32\x30.protos.common.DataClayObjectMetaData.HintsEntry\x12\x0f\n\x07numRefs\x18\x04 \x01(\x05\x12\x14\n\x0corigObjectID\x18\x05 \x01(\t\x12\x14\n\x0crootLocation\x18\x06 \x01(\t\x12\x16\n\x0eoriginLocation\x18\x07 \x01(\t\x12\x18\n\x10replicaLocations\x18\x08 \x03(\t\x12\r\n\x05\x61lias\x18\t \x01(\t\x12\x12\n\nisReadOnly\x18\n \x01(\x08\x12\x14\n\x0c\x64\x61taset_name\x18\x0b \x01(\t\x1a+\n\tOidsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a/\n\rClassidsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a,\n\nHintsEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x14PersistentObjectInDB\x12\x37\n\x08metadata\x18\x01 \x01(\x0b\x32%.protos.common.DataClayObjectMetaData\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"j\n\x10RegistrationInfo\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x0f\n\x07\x63lassID\x18\x02 \x01(\t\x12\x11\n\tsessionID\x18\x03 \x01(\t\x12\x11\n\tdataSetID\x18\x04 \x01(\t\x12\r\n\x05\x61lias\x18\x05 \x01(\t\"\\\n\x13\x46\x65\x64\x65ratedObjectInfo\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x11\n\tclassName\x18\x02 \x01(\t\x12\x11\n\tnameSpace\x18\x03 \x01(\t\x12\r\n\x05\x61lias\x18\x04 \x03(\t\"\xaf\x01\n\x11GetTracesResponse\x12<\n\x06traces\x18\x01 \x03(\x0b\x32,.protos.common.GetTracesResponse.TracesEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a-\n\x0bTracesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"[\n\rExceptionInfo\x12\x13\n\x0bisException\x18\x01 \x01(\x08\x12\x1b\n\x13serializedException\x18\x02 \x01(\x0c\x12\x18\n\x10\x65xceptionMessage\x18\x03 \x01(\x0c\"\x8f\x01\n\x0cMetaDataInfo\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x12\n\nisReadOnly\x18\x02 \x01(\x08\x12\x11\n\tdatasetID\x18\x03 \x01(\t\x12\x13\n\x0bmetaclassID\x18\x04 \x01(\t\x12\x11\n\tlocations\x18\x05 \x03(\t\x12\r\n\x05\x61lias\x18\x06 \x01(\t\x12\x0f\n\x07ownerID\x18\x07 \x01(\t\"O\n\x13StorageLocationInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\"\x98\x01\n\x18\x45xecutionEnvironmentInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12&\n\x08language\x18\x05 \x01(\x0e\x32\x14.protos.common.Langs\x12\x1a\n\x12\x64\x61taClayInstanceID\x18\x06 \x01(\t\"<\n\x10\x44\x61taClayInstance\x12\n\n\x02id\x18\x01 \x01(\t\x12\r\n\x05hosts\x18\x02 \x03(\t\x12\r\n\x05ports\x18\x03 \x03(\x05\"W\n\x15GetNumObjectsResponse\x12\x0f\n\x07numObjs\x18\x01 \x01(\x05\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x83\x01\n\x07\x42\x61\x63kend\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0f\n\x07sl_name\x18\x04 \x01(\t\x12&\n\x08language\x18\x05 \x01(\x0e\x32\x14.protos.common.Langs\x12\x13\n\x0b\x64\x61taclay_id\x18\x06 \x01(\t\"\xc9\x01\n\x0eObjectMetadata\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t\x12\x12\n\nclass_name\x18\x04 \x01(\t\x12\x12\n\nbackend_id\x18\x05 \x01(\t\x12\x1b\n\x13replica_backend_ids\x18\x06 \x03(\t\x12&\n\x08language\x18\x07 \x01(\x0e\x32\x14.protos.common.Langs\x12\x14\n\x0cis_read_only\x18\x08 \x01(\x08\"P\n\x07Session\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t\x12\x11\n\tis_active\x18\x04 \x01(\x08*6\n\x05Langs\x12\r\n\tLANG_NONE\x10\x00\x12\r\n\tLANG_JAVA\x10\x01\x12\x0f\n\x0bLANG_PYTHON\x10\x02\x42\x34\n2es.bsc.dataclay.communication.grpc.messages.commonb\x06proto3')

_LANGS = DESCRIPTOR.enum_types_by_name['Langs']
Langs = enum_type_wrapper.EnumTypeWrapper(_LANGS)
LANG_NONE = 0
LANG_JAVA = 1
LANG_PYTHON = 2


_CREDENTIAL = DESCRIPTOR.message_types_by_name['Credential']
_PARAMORRETURN = DESCRIPTOR.message_types_by_name['ParamOrReturn']
_EMPTYMESSAGE = DESCRIPTOR.message_types_by_name['EmptyMessage']
_SERIALIZEDPARAMETERSORRETURN = DESCRIPTOR.message_types_by_name['SerializedParametersOrReturn']
_SERIALIZEDPARAMETERSORRETURN_IMMPARAMSENTRY = _SERIALIZEDPARAMETERSORRETURN.nested_types_by_name['ImmParamsEntry']
_SERIALIZEDPARAMETERSORRETURN_LANGPARAMSENTRY = _SERIALIZEDPARAMETERSORRETURN.nested_types_by_name['LangParamsEntry']
_SERIALIZEDPARAMETERSORRETURN_VOLATILEPARAMSENTRY = _SERIALIZEDPARAMETERSORRETURN.nested_types_by_name['VolatileParamsEntry']
_SERIALIZEDPARAMETERSORRETURN_PERSPARAMSENTRY = _SERIALIZEDPARAMETERSORRETURN.nested_types_by_name['PersParamsEntry']
_IMMUTABLEPARAMORRETURN = DESCRIPTOR.message_types_by_name['ImmutableParamOrReturn']
_PERSISTENTPARAMORRETURN = DESCRIPTOR.message_types_by_name['PersistentParamOrReturn']
_OBJECTWITHDATAPARAMORRETURN = DESCRIPTOR.message_types_by_name['ObjectWithDataParamOrReturn']
_LANGUAGEPARAMORRETURN = DESCRIPTOR.message_types_by_name['LanguageParamOrReturn']
_DATACLAYOBJECTMETADATA = DESCRIPTOR.message_types_by_name['DataClayObjectMetaData']
_DATACLAYOBJECTMETADATA_OIDSENTRY = _DATACLAYOBJECTMETADATA.nested_types_by_name['OidsEntry']
_DATACLAYOBJECTMETADATA_CLASSIDSENTRY = _DATACLAYOBJECTMETADATA.nested_types_by_name['ClassidsEntry']
_DATACLAYOBJECTMETADATA_HINTSENTRY = _DATACLAYOBJECTMETADATA.nested_types_by_name['HintsEntry']
_PERSISTENTOBJECTINDB = DESCRIPTOR.message_types_by_name['PersistentObjectInDB']
_REGISTRATIONINFO = DESCRIPTOR.message_types_by_name['RegistrationInfo']
_FEDERATEDOBJECTINFO = DESCRIPTOR.message_types_by_name['FederatedObjectInfo']
_GETTRACESRESPONSE = DESCRIPTOR.message_types_by_name['GetTracesResponse']
_GETTRACESRESPONSE_TRACESENTRY = _GETTRACESRESPONSE.nested_types_by_name['TracesEntry']
_EXCEPTIONINFO = DESCRIPTOR.message_types_by_name['ExceptionInfo']
_METADATAINFO = DESCRIPTOR.message_types_by_name['MetaDataInfo']
_STORAGELOCATIONINFO = DESCRIPTOR.message_types_by_name['StorageLocationInfo']
_EXECUTIONENVIRONMENTINFO = DESCRIPTOR.message_types_by_name['ExecutionEnvironmentInfo']
_DATACLAYINSTANCE = DESCRIPTOR.message_types_by_name['DataClayInstance']
_GETNUMOBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['GetNumObjectsResponse']
_BACKEND = DESCRIPTOR.message_types_by_name['Backend']
_OBJECTMETADATA = DESCRIPTOR.message_types_by_name['ObjectMetadata']
_SESSION = DESCRIPTOR.message_types_by_name['Session']
Credential = _reflection.GeneratedProtocolMessageType('Credential', (_message.Message,), {
  'DESCRIPTOR' : _CREDENTIAL,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.Credential)
  })
_sym_db.RegisterMessage(Credential)

ParamOrReturn = _reflection.GeneratedProtocolMessageType('ParamOrReturn', (_message.Message,), {
  'DESCRIPTOR' : _PARAMORRETURN,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.ParamOrReturn)
  })
_sym_db.RegisterMessage(ParamOrReturn)

EmptyMessage = _reflection.GeneratedProtocolMessageType('EmptyMessage', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYMESSAGE,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.EmptyMessage)
  })
_sym_db.RegisterMessage(EmptyMessage)

SerializedParametersOrReturn = _reflection.GeneratedProtocolMessageType('SerializedParametersOrReturn', (_message.Message,), {

  'ImmParamsEntry' : _reflection.GeneratedProtocolMessageType('ImmParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERIALIZEDPARAMETERSORRETURN_IMMPARAMSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.SerializedParametersOrReturn.ImmParamsEntry)
    })
  ,

  'LangParamsEntry' : _reflection.GeneratedProtocolMessageType('LangParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERIALIZEDPARAMETERSORRETURN_LANGPARAMSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.SerializedParametersOrReturn.LangParamsEntry)
    })
  ,

  'VolatileParamsEntry' : _reflection.GeneratedProtocolMessageType('VolatileParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERIALIZEDPARAMETERSORRETURN_VOLATILEPARAMSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.SerializedParametersOrReturn.VolatileParamsEntry)
    })
  ,

  'PersParamsEntry' : _reflection.GeneratedProtocolMessageType('PersParamsEntry', (_message.Message,), {
    'DESCRIPTOR' : _SERIALIZEDPARAMETERSORRETURN_PERSPARAMSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.SerializedParametersOrReturn.PersParamsEntry)
    })
  ,
  'DESCRIPTOR' : _SERIALIZEDPARAMETERSORRETURN,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.SerializedParametersOrReturn)
  })
_sym_db.RegisterMessage(SerializedParametersOrReturn)
_sym_db.RegisterMessage(SerializedParametersOrReturn.ImmParamsEntry)
_sym_db.RegisterMessage(SerializedParametersOrReturn.LangParamsEntry)
_sym_db.RegisterMessage(SerializedParametersOrReturn.VolatileParamsEntry)
_sym_db.RegisterMessage(SerializedParametersOrReturn.PersParamsEntry)

ImmutableParamOrReturn = _reflection.GeneratedProtocolMessageType('ImmutableParamOrReturn', (_message.Message,), {
  'DESCRIPTOR' : _IMMUTABLEPARAMORRETURN,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.ImmutableParamOrReturn)
  })
_sym_db.RegisterMessage(ImmutableParamOrReturn)

PersistentParamOrReturn = _reflection.GeneratedProtocolMessageType('PersistentParamOrReturn', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTPARAMORRETURN,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.PersistentParamOrReturn)
  })
_sym_db.RegisterMessage(PersistentParamOrReturn)

ObjectWithDataParamOrReturn = _reflection.GeneratedProtocolMessageType('ObjectWithDataParamOrReturn', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTWITHDATAPARAMORRETURN,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.ObjectWithDataParamOrReturn)
  })
_sym_db.RegisterMessage(ObjectWithDataParamOrReturn)

LanguageParamOrReturn = _reflection.GeneratedProtocolMessageType('LanguageParamOrReturn', (_message.Message,), {
  'DESCRIPTOR' : _LANGUAGEPARAMORRETURN,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.LanguageParamOrReturn)
  })
_sym_db.RegisterMessage(LanguageParamOrReturn)

DataClayObjectMetaData = _reflection.GeneratedProtocolMessageType('DataClayObjectMetaData', (_message.Message,), {

  'OidsEntry' : _reflection.GeneratedProtocolMessageType('OidsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATACLAYOBJECTMETADATA_OIDSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.DataClayObjectMetaData.OidsEntry)
    })
  ,

  'ClassidsEntry' : _reflection.GeneratedProtocolMessageType('ClassidsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATACLAYOBJECTMETADATA_CLASSIDSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.DataClayObjectMetaData.ClassidsEntry)
    })
  ,

  'HintsEntry' : _reflection.GeneratedProtocolMessageType('HintsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATACLAYOBJECTMETADATA_HINTSENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.DataClayObjectMetaData.HintsEntry)
    })
  ,
  'DESCRIPTOR' : _DATACLAYOBJECTMETADATA,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.DataClayObjectMetaData)
  })
_sym_db.RegisterMessage(DataClayObjectMetaData)
_sym_db.RegisterMessage(DataClayObjectMetaData.OidsEntry)
_sym_db.RegisterMessage(DataClayObjectMetaData.ClassidsEntry)
_sym_db.RegisterMessage(DataClayObjectMetaData.HintsEntry)

PersistentObjectInDB = _reflection.GeneratedProtocolMessageType('PersistentObjectInDB', (_message.Message,), {
  'DESCRIPTOR' : _PERSISTENTOBJECTINDB,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.PersistentObjectInDB)
  })
_sym_db.RegisterMessage(PersistentObjectInDB)

RegistrationInfo = _reflection.GeneratedProtocolMessageType('RegistrationInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGISTRATIONINFO,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.RegistrationInfo)
  })
_sym_db.RegisterMessage(RegistrationInfo)

FederatedObjectInfo = _reflection.GeneratedProtocolMessageType('FederatedObjectInfo', (_message.Message,), {
  'DESCRIPTOR' : _FEDERATEDOBJECTINFO,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.FederatedObjectInfo)
  })
_sym_db.RegisterMessage(FederatedObjectInfo)

GetTracesResponse = _reflection.GeneratedProtocolMessageType('GetTracesResponse', (_message.Message,), {

  'TracesEntry' : _reflection.GeneratedProtocolMessageType('TracesEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETTRACESRESPONSE_TRACESENTRY,
    '__module__' : 'protos.common_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.common.GetTracesResponse.TracesEntry)
    })
  ,
  'DESCRIPTOR' : _GETTRACESRESPONSE,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.GetTracesResponse)
  })
_sym_db.RegisterMessage(GetTracesResponse)
_sym_db.RegisterMessage(GetTracesResponse.TracesEntry)

ExceptionInfo = _reflection.GeneratedProtocolMessageType('ExceptionInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXCEPTIONINFO,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.ExceptionInfo)
  })
_sym_db.RegisterMessage(ExceptionInfo)

MetaDataInfo = _reflection.GeneratedProtocolMessageType('MetaDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _METADATAINFO,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.MetaDataInfo)
  })
_sym_db.RegisterMessage(MetaDataInfo)

StorageLocationInfo = _reflection.GeneratedProtocolMessageType('StorageLocationInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGELOCATIONINFO,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.StorageLocationInfo)
  })
_sym_db.RegisterMessage(StorageLocationInfo)

ExecutionEnvironmentInfo = _reflection.GeneratedProtocolMessageType('ExecutionEnvironmentInfo', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTIONENVIRONMENTINFO,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.ExecutionEnvironmentInfo)
  })
_sym_db.RegisterMessage(ExecutionEnvironmentInfo)

DataClayInstance = _reflection.GeneratedProtocolMessageType('DataClayInstance', (_message.Message,), {
  'DESCRIPTOR' : _DATACLAYINSTANCE,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.DataClayInstance)
  })
_sym_db.RegisterMessage(DataClayInstance)

GetNumObjectsResponse = _reflection.GeneratedProtocolMessageType('GetNumObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETNUMOBJECTSRESPONSE,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.GetNumObjectsResponse)
  })
_sym_db.RegisterMessage(GetNumObjectsResponse)

Backend = _reflection.GeneratedProtocolMessageType('Backend', (_message.Message,), {
  'DESCRIPTOR' : _BACKEND,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.Backend)
  })
_sym_db.RegisterMessage(Backend)

ObjectMetadata = _reflection.GeneratedProtocolMessageType('ObjectMetadata', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTMETADATA,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.ObjectMetadata)
  })
_sym_db.RegisterMessage(ObjectMetadata)

Session = _reflection.GeneratedProtocolMessageType('Session', (_message.Message,), {
  'DESCRIPTOR' : _SESSION,
  '__module__' : 'protos.common_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.common.Session)
  })
_sym_db.RegisterMessage(Session)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n2es.bsc.dataclay.communication.grpc.messages.common'
  _SERIALIZEDPARAMETERSORRETURN_IMMPARAMSENTRY._options = None
  _SERIALIZEDPARAMETERSORRETURN_IMMPARAMSENTRY._serialized_options = b'8\001'
  _SERIALIZEDPARAMETERSORRETURN_LANGPARAMSENTRY._options = None
  _SERIALIZEDPARAMETERSORRETURN_LANGPARAMSENTRY._serialized_options = b'8\001'
  _SERIALIZEDPARAMETERSORRETURN_VOLATILEPARAMSENTRY._options = None
  _SERIALIZEDPARAMETERSORRETURN_VOLATILEPARAMSENTRY._serialized_options = b'8\001'
  _SERIALIZEDPARAMETERSORRETURN_PERSPARAMSENTRY._options = None
  _SERIALIZEDPARAMETERSORRETURN_PERSPARAMSENTRY._serialized_options = b'8\001'
  _DATACLAYOBJECTMETADATA_OIDSENTRY._options = None
  _DATACLAYOBJECTMETADATA_OIDSENTRY._serialized_options = b'8\001'
  _DATACLAYOBJECTMETADATA_CLASSIDSENTRY._options = None
  _DATACLAYOBJECTMETADATA_CLASSIDSENTRY._serialized_options = b'8\001'
  _DATACLAYOBJECTMETADATA_HINTSENTRY._options = None
  _DATACLAYOBJECTMETADATA_HINTSENTRY._serialized_options = b'8\001'
  _GETTRACESRESPONSE_TRACESENTRY._options = None
  _GETTRACESRESPONSE_TRACESENTRY._serialized_options = b'8\001'
  _LANGS._serialized_start=3335
  _LANGS._serialized_end=3389
  _CREDENTIAL._serialized_start=47
  _CREDENTIAL._serialized_end=77
  _PARAMORRETURN._serialized_start=79
  _PARAMORRETURN._serialized_end=137
  _EMPTYMESSAGE._serialized_start=139
  _EMPTYMESSAGE._serialized_end=153
  _SERIALIZEDPARAMETERSORRETURN._serialized_start=156
  _SERIALIZEDPARAMETERSORRETURN._serialized_end=903
  _SERIALIZEDPARAMETERSORRETURN_IMMPARAMSENTRY._serialized_start=537
  _SERIALIZEDPARAMETERSORRETURN_IMMPARAMSENTRY._serialized_end=624
  _SERIALIZEDPARAMETERSORRETURN_LANGPARAMSENTRY._serialized_start=626
  _SERIALIZEDPARAMETERSORRETURN_LANGPARAMSENTRY._serialized_end=713
  _SERIALIZEDPARAMETERSORRETURN_VOLATILEPARAMSENTRY._serialized_start=715
  _SERIALIZEDPARAMETERSORRETURN_VOLATILEPARAMSENTRY._serialized_end=812
  _SERIALIZEDPARAMETERSORRETURN_PERSPARAMSENTRY._serialized_start=814
  _SERIALIZEDPARAMETERSORRETURN_PERSPARAMSENTRY._serialized_end=903
  _IMMUTABLEPARAMORRETURN._serialized_start=905
  _IMMUTABLEPARAMORRETURN._serialized_end=947
  _PERSISTENTPARAMORRETURN._serialized_start=949
  _PERSISTENTPARAMORRETURN._serialized_end=1041
  _OBJECTWITHDATAPARAMORRETURN._serialized_start=1044
  _OBJECTWITHDATAPARAMORRETURN._serialized_end=1178
  _LANGUAGEPARAMORRETURN._serialized_start=1180
  _LANGUAGEPARAMORRETURN._serialized_end=1278
  _DATACLAYOBJECTMETADATA._serialized_start=1281
  _DATACLAYOBJECTMETADATA._serialized_end=1812
  _DATACLAYOBJECTMETADATA_OIDSENTRY._serialized_start=1674
  _DATACLAYOBJECTMETADATA_OIDSENTRY._serialized_end=1717
  _DATACLAYOBJECTMETADATA_CLASSIDSENTRY._serialized_start=1719
  _DATACLAYOBJECTMETADATA_CLASSIDSENTRY._serialized_end=1766
  _DATACLAYOBJECTMETADATA_HINTSENTRY._serialized_start=1768
  _DATACLAYOBJECTMETADATA_HINTSENTRY._serialized_end=1812
  _PERSISTENTOBJECTINDB._serialized_start=1814
  _PERSISTENTOBJECTINDB._serialized_end=1907
  _REGISTRATIONINFO._serialized_start=1909
  _REGISTRATIONINFO._serialized_end=2015
  _FEDERATEDOBJECTINFO._serialized_start=2017
  _FEDERATEDOBJECTINFO._serialized_end=2109
  _GETTRACESRESPONSE._serialized_start=2112
  _GETTRACESRESPONSE._serialized_end=2287
  _GETTRACESRESPONSE_TRACESENTRY._serialized_start=2242
  _GETTRACESRESPONSE_TRACESENTRY._serialized_end=2287
  _EXCEPTIONINFO._serialized_start=2289
  _EXCEPTIONINFO._serialized_end=2380
  _METADATAINFO._serialized_start=2383
  _METADATAINFO._serialized_end=2526
  _STORAGELOCATIONINFO._serialized_start=2528
  _STORAGELOCATIONINFO._serialized_end=2607
  _EXECUTIONENVIRONMENTINFO._serialized_start=2610
  _EXECUTIONENVIRONMENTINFO._serialized_end=2762
  _DATACLAYINSTANCE._serialized_start=2764
  _DATACLAYINSTANCE._serialized_end=2824
  _GETNUMOBJECTSRESPONSE._serialized_start=2826
  _GETNUMOBJECTSRESPONSE._serialized_end=2913
  _BACKEND._serialized_start=2916
  _BACKEND._serialized_end=3047
  _OBJECTMETADATA._serialized_start=3050
  _OBJECTMETADATA._serialized_end=3251
  _SESSION._serialized_start=3253
  _SESSION._serialized_end=3333
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/dataservice_messages.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_messages_pb2 as protos_dot_common__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!protos/dataservice_messages.proto\x12\x12protos.dataservice\x1a\x1cprotos/common_messages.proto\")\n\x14InitBackendIDRequest\x12\x11\n\tbackendID\x18\x01 \x01(\t\"F\n$AssociateExecutionEnvironmentRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\"\xbe\x01\n\x18\x44\x65ployMetaClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12X\n\x0e\x64\x65ploymentPack\x18\x02 \x03(\x0b\x32@.protos.dataservice.DeployMetaClassesRequest.DeploymentPackEntry\x1a\x35\n\x13\x44\x65ploymentPackEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x9e\x04\n\x14\x44\x65ployClassesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12V\n\x0f\x63lassesToDeploy\x18\x02 \x03(\x0b\x32=.protos.dataservice.DeployClassesRequest.ClassesToDeployEntry\x12H\n\x08\x63lassIds\x18\x03 \x03(\x0b\x32\x36.protos.dataservice.DeployClassesRequest.ClassIdsEntry\x12\x46\n\x07\x61spects\x18\x04 \x03(\x0b\x32\x35.protos.dataservice.DeployClassesRequest.AspectsEntry\x12\x42\n\x05yamls\x18\x05 \x03(\x0b\x32\x33.protos.dataservice.DeployClassesRequest.YamlsEntry\x1a\x36\n\x14\x43lassesToDeployEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a/\n\rClassIdsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a.\n\x0c\x41spectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1a,\n\nYamlsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"o\n\x12\x45nrichClassRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x11\n\tclassname\x18\x02 \x01(\t\x12\x15\n\rclassToDeploy\x18\x03 \x01(\x0c\x12\x0e\n\x06\x61spect\x18\x04 \x01(\x0c\x12\x0c\n\x04yaml\x18\x05 \x01(\x0c\"\xa8\x02\n\x1cNewPersistentInstanceRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x0f\n\x07\x63lassID\x18\x02 \x01(\t\x12\x18\n\x10implementationID\x18\x03 \x01(\t\x12X\n\x0cifaceBitMaps\x18\x04 \x03(\x0b\x32\x42.protos.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry\x12;\n\x06params\x18\x05 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x1a\x33\n\x11IfaceBitMapsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"`\n\x1dNewPersistentInstanceResponse\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x8b\x01\n\x13StoreObjectsRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12;\n\x07objects\x18\x02 \x03(\x0b\x32*.protos.common.ObjectWithDataParamOrReturn\x12\x0e\n\x06moving\x18\x03 \x01(\x08\x12\x14\n\x0cidsWithAlias\x18\x04 \x03(\t\"P\n\x16GetCopyOfObjectRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\"\x82\x01\n\x17GetCopyOfObjectResponse\x12\x38\n\x03ret\x18\x01 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x7f\n\x13UpdateObjectRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x14\n\x0cintoObjectID\x18\x02 \x01(\t\x12?\n\nfromObject\x18\x03 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\"\x9e\x01\n\x11GetObjectsRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x11\n\tobjectIDS\x18\x02 \x03(\t\x12\x1e\n\x16\x61lreadyObtainedObjects\x18\x03 \x03(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\x12\x15\n\rdestBackendID\x18\x05 \x01(\t\x12\x19\n\x11updateReplicaLocs\x18\x06 \x01(\x05\"\x80\x01\n\x12GetObjectsResponse\x12;\n\x07objects\x18\x01 \x03(\x0b\x32*.protos.common.ObjectWithDataParamOrReturn\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"j\n\x18OldMakePersistentRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12;\n\x07objects\x18\x02 \x03(\x0b\x32*.protos.common.ObjectWithDataParamOrReturn\"q\n\x0f\x46\x65\x64\x65rateRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12&\n\x1e\x65xternalExecutionEnvironmentID\x18\x03 \x01(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\"i\n\x17NotifyFederationRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12;\n\x07objects\x18\x02 \x03(\x0b\x32*.protos.common.ObjectWithDataParamOrReturn\"s\n\x11UnfederateRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12&\n\x1e\x65xternalExecutionEnvironmentID\x18\x03 \x01(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\"A\n\x19NotifyUnfederationRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x11\n\tobjectIDs\x18\x02 \x03(\t\"\x9a\x01\n\x1c\x45xecuteImplementationRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x18\n\x10implementationID\x18\x02 \x01(\t\x12\x11\n\tsessionID\x18\x03 \x01(\t\x12;\n\x06params\x18\x04 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\"\x88\x01\n\x1d\x45xecuteImplementationResponse\x12\x38\n\x03ret\x18\x01 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"O\n\x11NewVersionRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x15\n\rdestBackendID\x18\x03 \x01(\t\"U\n\x12NewVersionResponse\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"G\n\x19\x43onsolidateVersionRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x17\n\x0fversionObjectID\x18\x02 \x01(\t\"j\n\x14UpsertObjectsRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12?\n\x0b\x62ytesUpdate\x18\x02 \x03(\x0b\x32*.protos.common.ObjectWithDataParamOrReturn\"b\n\x11NewReplicaRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x15\n\rdestBackendID\x18\x03 \x01(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\"^\n\x12NewReplicaResponse\x12\x19\n\x11replicatedObjects\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"_\n\x12MoveObjectsRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x11\n\tdestLocID\x18\x03 \x01(\t\x12\x11\n\trecursive\x18\x04 \x01(\x08\"Z\n\x13MoveObjectsResponse\x12\x14\n\x0cmovedObjects\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"p\n\x14RemoveObjectsRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\x12\x11\n\tobjectIDs\x18\x02 \x03(\t\x12\x11\n\trecursive\x18\x03 \x01(\x08\x12\x0e\n\x06moving\x18\x04 \x01(\x08\x12\x0f\n\x07newHint\x18\x05 \x01(\t\"\xd4\x01\n\x15RemoveObjectsResponse\x12U\n\x0eremovedObjects\x18\x01 \x03(\x0b\x32=.protos.dataservice.RemoveObjectsResponse.RemovedObjectsEntry\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1a\x35\n\x13RemovedObjectsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xcc\x01\n\x15MigrateObjectsRequest\x12W\n\x0f\x64\x65stStorageLocs\x18\x01 \x03(\x0b\x32>.protos.dataservice.MigrateObjectsRequest.DestStorageLocsEntry\x1aZ\n\x14\x44\x65stStorageLocsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x31\n\x05value\x18\x02 \x01(\x0b\x32\".protos.common.StorageLocationInfo:\x02\x38\x01\"\x1f\n\x0fMigratedObjects\x12\x0c\n\x04objs\x18\x01 \x03(\t\"\xb3\x02\n\x16MigrateObjectsResponse\x12R\n\x0cmigratedObjs\x18\x01 \x03(\x0b\x32<.protos.dataservice.MigrateObjectsResponse.MigratedObjsEntry\x12<\n\x0fnonMigratedObjs\x18\x02 \x01(\x0b\x32#.protos.dataservice.MigratedObjects\x12-\n\x07\x65xcInfo\x18\x03 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\x1aX\n\x11MigratedObjsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.protos.dataservice.MigratedObjects:\x02\x38\x01\"(\n\x16\x41\x63tivateTracingRequest\x12\x0e\n\x06taskid\x18\x01 \x01(\x05\",\n\x17\x43loseSessionInDSRequest\x12\x11\n\tsessionID\x18\x01 \x01(\t\"\xd4\x01\n\x12\x44iskCollectRequest\x12\x13\n\x0b\x65pochNodeID\x18\x01 \x01(\t\x12\x10\n\x08ringPath\x18\x02 \x03(\t\x12\x12\n\ncandidates\x18\x03 \x03(\t\x12N\n\x0crefsToUpdate\x18\x04 \x03(\x0b\x32\x38.protos.dataservice.DiskCollectRequest.RefsToUpdateEntry\x1a\x33\n\x11RefsToUpdateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"7\n#GetClassIDFromObjectInMemoryRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\"f\n$GetClassIDFromObjectInMemoryResponse\x12\x0f\n\x07\x63lassID\x18\x01 \x01(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"V\n\x10StoreToDBRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x10\n\x08objBytes\x18\x03 \x01(\x0c\"D\n\x10GetFromDBRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\"T\n\x11GetFromDBResponse\x12\x10\n\x08objBytes\x18\x01 \x01(\x0c\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"f\n\x11UpdateToDBRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\x12\x10\n\x08objBytes\x18\x03 \x01(\x0c\x12\r\n\x05\x64irty\x18\x04 \x01(\x08\"E\n\x11\x44\x65leteToDBRequest\x12\x1e\n\x16\x65xecutionEnvironmentID\x18\x01 \x01(\t\x12\x10\n\x08objectID\x18\x02 \x01(\t\"Z\n\x16\x44\x65leteSetFromDBRequest\x12\x11\n\tobjectIDs\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\x97\x01\n\x11UpdateRefsRequest\x12M\n\x0crefsToUpdate\x18\x01 \x03(\x0b\x32\x37.protos.dataservice.UpdateRefsRequest.RefsToUpdateEntry\x1a\x33\n\x11RefsToUpdateEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x05:\x02\x38\x01\"j\n\x1dGetRetainedReferencesResponse\x12\x1a\n\x12retainedReferences\x18\x01 \x03(\t\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"\xaa\x01\n\x12SynchronizeRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x18\n\x10implementationID\x18\x02 \x01(\t\x12\x11\n\tsessionID\x18\x03 \x01(\t\x12;\n\x06params\x18\x04 \x01(\x0b\x32+.protos.common.SerializedParametersOrReturn\x12\x18\n\x10\x63\x61llingBackendID\x18\x05 \x01(\t\"!\n\rExistsRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\"O\n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"%\n\x11\x45xistsInDBRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\"S\n\x12\x45xistsInDBResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfo\"E\n\x1e\x44\x65tachObjectFromSessionRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x11\n\tsessionID\x18\x02 \x01(\t\"9\n\x12\x44\x65leteAliasRequest\x12\x10\n\x08objectID\x18\x01 \x01(\t\x12\x11\n\tsessionID\x18\x02 \x01(\t\"`\n\x16GetObjectGraphResponse\x12\x17\n\x0fserializedGraph\x18\x01 \x01(\x0c\x12-\n\x07\x65xcInfo\x18\x02 \x01(\x0b\x32\x1c.protos.common.ExceptionInfoB;\n7es.bsc.dataclay.communication.grpc.messages.dataserviceP\x00\x62\x06proto3')



_INITBACKENDIDREQUEST = DESCRIPTOR.message_types_by_name['InitBackendIDRequest']
_ASSOCIATEEXECUTIONENVIRONMENTREQUEST = DESCRIPTOR.message_types_by_name['AssociateExecutionEnvironmentRequest']
_DEPLOYMETACLASSESREQUEST = DESCRIPTOR.message_types_by_name['DeployMetaClassesRequest']
_DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY = _DEPLOYMETACLASSESREQUEST.nested_types_by_name['DeploymentPackEntry']
_DEPLOYCLASSESREQUEST = DESCRIPTOR.message_types_by_name['DeployClassesRequest']
_DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY = _DEPLOYCLASSESREQUEST.nested_types_by_name['ClassesToDeployEntry']
_DEPLOYCLASSESREQUEST_CLASSIDSENTRY = _DEPLOYCLASSESREQUEST.nested_types_by_name['ClassIdsEntry']
_DEPLOYCLASSESREQUEST_ASPECTSENTRY = _DEPLOYCLASSESREQUEST.nested_types_by_name['AspectsEntry']
_DEPLOYCLASSESREQUEST_YAMLSENTRY = _DEPLOYCLASSESREQUEST.nested_types_by_name['YamlsEntry']
_ENRICHCLASSREQUEST = DESCRIPTOR.message_types_by_name['EnrichClassRequest']
_NEWPERSISTENTINSTANCEREQUEST = DESCRIPTOR.message_types_by_name['NewPersistentInstanceRequest']
_NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY = _NEWPERSISTENTINSTANCEREQUEST.nested_types_by_name['IfaceBitMapsEntry']
_NEWPERSISTENTINSTANCERESPONSE = DESCRIPTOR.message_types_by_name['NewPersistentInstanceResponse']
_STOREOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['StoreObjectsRequest']
_GETCOPYOFOBJECTREQUEST = DESCRIPTOR.message_types_by_name['GetCopyOfObjectRequest']
_GETCOPYOFOBJECTRESPONSE = DESCRIPTOR.message_types_by_name['GetCopyOfObjectResponse']
_UPDATEOBJECTREQUEST = DESCRIPTOR.message_types_by_name['UpdateObjectRequest']
_GETOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['GetObjectsRequest']
_GETOBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['GetObjectsResponse']
_OLDMAKEPERSISTENTREQUEST = DESCRIPTOR.message_types_by_name['OldMakePersistentRequest']
_FEDERATEREQUEST = DESCRIPTOR.message_types_by_name['FederateRequest']
_NOTIFYFEDERATIONREQUEST = DESCRIPTOR.message_types_by_name['NotifyFederationRequest']
_UNFEDERATEREQUEST = DESCRIPTOR.message_types_by_name['UnfederateRequest']
_NOTIFYUNFEDERATIONREQUEST = DESCRIPTOR.message_types_by_name['NotifyUnfederationRequest']
_EXECUTEIMPLEMENTATIONREQUEST = DESCRIPTOR.message_types_by_name['ExecuteImplementationRequest']
_EXECUTEIMPLEMENTATIONRESPONSE = DESCRIPTOR.message_types_by_name['ExecuteImplementationResponse']
_NEWVERSIONREQUEST = DESCRIPTOR.message_types_by_name['NewVersionRequest']
_NEWVERSIONRESPONSE = DESCRIPTOR.message_types_by_name['NewVersionResponse']
_CONSOLIDATEVERSIONREQUEST = DESCRIPTOR.message_types_by_name['ConsolidateVersionRequest']
_UPSERTOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['UpsertObjectsRequest']
_NEWREPLICAREQUEST = DESCRIPTOR.message_types_by_name['NewReplicaRequest']
_NEWREPLICARESPONSE = DESCRIPTOR.message_types_by_name['NewReplicaResponse']
_MOVEOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['MoveObjectsRequest']
_MOVEOBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['MoveObjectsResponse']
_REMOVEOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['RemoveObjectsRequest']
_REMOVEOBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['RemoveObjectsResponse']
_REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY = _REMOVEOBJECTSRESPONSE.nested_types_by_name['RemovedObjectsEntry']
_MIGRATEOBJECTSREQUEST = DESCRIPTOR.message_types_by_name['MigrateObjectsRequest']
_MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY = _MIGRATEOBJECTSREQUEST.nested_types_by_name['DestStorageLocsEntry']
_MIGRATEDOBJECTS = DESCRIPTOR.message_types_by_name['MigratedObjects']
_MIGRATEOBJECTSRESPONSE = DESCRIPTOR.message_types_by_name['MigrateObjectsResponse']
_MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY = _MIGRATEOBJECTSRESPONSE.nested_types_by_name['MigratedObjsEntry']
_ACTIVATETRACINGREQUEST = DESCRIPTOR.message_types_by_name['ActivateTracingRequest']
_CLOSESESSIONINDSREQUEST = DESCRIPTOR.message_types_by_name['CloseSessionInDSRequest']
_DISKCOLLECTREQUEST = DESCRIPTOR.message_types_by_name['DiskCollectRequest']
_DISKCOLLECTREQUEST_REFSTOUPDATEENTRY = _DISKCOLLECTREQUEST.nested_types_by_name['RefsToUpdateEntry']
_GETCLASSIDFROMOBJECTINMEMORYREQUEST = DESCRIPTOR.message_types_by_name['GetClassIDFromObjectInMemoryRequest']
_GETCLASSIDFROMOBJECTINMEMORYRESPONSE = DESCRIPTOR.message_types_by_name['GetClassIDFromObjectInMemoryResponse']
_STORETODBREQUEST = DESCRIPTOR.message_types_by_name['StoreToDBRequest']
_GETFROMDBREQUEST = DESCRIPTOR.message_types_by_name['GetFromDBRequest']
_GETFROMDBRESPONSE = DESCRIPTOR.message_types_by_name['GetFromDBResponse']
_UPDATETODBREQUEST = DESCRIPTOR.message_types_by_name['UpdateToDBRequest']
_DELETETODBREQUEST = DESCRIPTOR.message_types_by_name['DeleteToDBRequest']
_DELETESETFROMDBREQUEST = DESCRIPTOR.message_types_by_name['DeleteSetFromDBRequest']
_UPDATEREFSREQUEST = DESCRIPTOR.message_types_by_name['UpdateRefsRequest']
_UPDATEREFSREQUEST_REFSTOUPDATEENTRY = _UPDATEREFSREQUEST.nested_types_by_name['RefsToUpdateEntry']
_GETRETAINEDREFERENCESRESPONSE = DESCRIPTOR.message_types_by_name['GetRetainedReferencesResponse']
_SYNCHRONIZEREQUEST = DESCRIPTOR.message_types_by_name['SynchronizeRequest']
_EXISTSREQUEST = DESCRIPTOR.message_types_by_name['ExistsRequest']
_EXISTSRESPONSE = DESCRIPTOR.message_types_by_name['ExistsResponse']
_EXISTSINDBREQUEST = DESCRIPTOR.message_types_by_name['ExistsInDBRequest']
_EXISTSINDBRESPONSE = DESCRIPTOR.message_types_by_name['ExistsInDBResponse']
_DETACHOBJECTFROMSESSIONREQUEST = DESCRIPTOR.message_types_by_name['DetachObjectFromSessionRequest']
_DELETEALIASREQUEST = DESCRIPTOR.message_types_by_name['DeleteAliasRequest']
_GETOBJECTGRAPHRESPONSE = DESCRIPTOR.message_types_by_name['GetObjectGraphResponse']
InitBackendIDRequest = _reflection.GeneratedProtocolMessageType('InitBackendIDRequest', (_message.Message,), {
  'DESCRIPTOR' : _INITBACKENDIDREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.InitBackendIDRequest)
  })
_sym_db.RegisterMessage(InitBackendIDRequest)

AssociateExecutionEnvironmentRequest = _reflection.GeneratedProtocolMessageType('AssociateExecutionEnvironmentRequest', (_message.Message,), {
  'DESCRIPTOR' : _ASSOCIATEEXECUTIONENVIRONMENTREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.AssociateExecutionEnvironmentRequest)
  })
_sym_db.RegisterMessage(AssociateExecutionEnvironmentRequest)

DeployMetaClassesRequest = _reflection.GeneratedProtocolMessageType('DeployMetaClassesRequest', (_message.Message,), {

  'DeploymentPackEntry' : _reflection.GeneratedProtocolMessageType('DeploymentPackEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.DeployMetaClassesRequest.DeploymentPackEntry)
    })
  ,
  'DESCRIPTOR' : _DEPLOYMETACLASSESREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DeployMetaClassesRequest)
  })
_sym_db.RegisterMessage(DeployMetaClassesRequest)
_sym_db.RegisterMessage(DeployMetaClassesRequest.DeploymentPackEntry)

DeployClassesRequest = _reflection.GeneratedProtocolMessageType('DeployClassesRequest', (_message.Message,), {

  'ClassesToDeployEntry' : _reflection.GeneratedProtocolMessageType('ClassesToDeployEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.DeployClassesRequest.ClassesToDeployEntry)
    })
  ,

  'ClassIdsEntry' : _reflection.GeneratedProtocolMessageType('ClassIdsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYCLASSESREQUEST_CLASSIDSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.DeployClassesRequest.ClassIdsEntry)
    })
  ,

  'AspectsEntry' : _reflection.GeneratedProtocolMessageType('AspectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYCLASSESREQUEST_ASPECTSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.DeployClassesRequest.AspectsEntry)
    })
  ,

  'YamlsEntry' : _reflection.GeneratedProtocolMessageType('YamlsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DEPLOYCLASSESREQUEST_YAMLSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.DeployClassesRequest.YamlsEntry)
    })
  ,
  'DESCRIPTOR' : _DEPLOYCLASSESREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DeployClassesRequest)
  })
_sym_db.RegisterMessage(DeployClassesRequest)
_sym_db.RegisterMessage(DeployClassesRequest.ClassesToDeployEntry)
_sym_db.RegisterMessage(DeployClassesRequest.ClassIdsEntry)
_sym_db.RegisterMessage(DeployClassesRequest.AspectsEntry)
_sym_db.RegisterMessage(DeployClassesRequest.YamlsEntry)

EnrichClassRequest = _reflection.GeneratedProtocolMessageType('EnrichClassRequest', (_message.Message,), {
  'DESCRIPTOR' : _ENRICHCLASSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.EnrichClassRequest)
  })
_sym_db.RegisterMessage(EnrichClassRequest)

NewPersistentInstanceRequest = _reflection.GeneratedProtocolMessageType('NewPersistentInstanceRequest', (_message.Message,), {

  'IfaceBitMapsEntry' : _reflection.GeneratedProtocolMessageType('IfaceBitMapsEntry', (_message.Message,), {
    'DESCRIPTOR' : _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.NewPersistentInstanceRequest.IfaceBitMapsEntry)
    })
  ,
  'DESCRIPTOR' : _NEWPERSISTENTINSTANCEREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NewPersistentInstanceRequest)
  })
_sym_db.RegisterMessage(NewPersistentInstanceRequest)
_sym_db.RegisterMessage(NewPersistentInstanceRequest.IfaceBitMapsEntry)

NewPersistentInstanceResponse = _reflection.GeneratedProtocolMessageType('NewPersistentInstanceResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWPERSISTENTINSTANCERESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NewPersistentInstanceResponse)
  })
_sym_db.RegisterMessage(NewPersistentInstanceResponse)

StoreObjectsRequest = _reflection.GeneratedProtocolMessageType('StoreObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _STOREOBJECTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.StoreObjectsRequest)
  })
_sym_db.RegisterMessage(StoreObjectsRequest)

GetCopyOfObjectRequest = _reflection.GeneratedProtocolMessageType('GetCopyOfObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOPYOFOBJECTREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetCopyOfObjectRequest)
  })
_sym_db.RegisterMessage(GetCopyOfObjectRequest)

GetCopyOfObjectResponse = _reflection.GeneratedProtocolMessageType('GetCopyOfObjectResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCOPYOFOBJECTRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetCopyOfObjectResponse)
  })
_sym_db.RegisterMessage(GetCopyOfObjectResponse)

UpdateObjectRequest = _reflection.GeneratedProtocolMessageType('UpdateObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEOBJECTREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.UpdateObjectRequest)
  })
_sym_db.RegisterMessage(UpdateObjectRequest)

GetObjectsRequest = _reflection.GeneratedProtocolMessageType('GetObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetObjectsRequest)
  })
_sym_db.RegisterMessage(GetObjectsRequest)

GetObjectsResponse = _reflection.GeneratedProtocolMessageType('GetObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTSRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetObjectsResponse)
  })
_sym_db.RegisterMessage(GetObjectsResponse)

OldMakePersistentRequest = _reflection.GeneratedProtocolMessageType('OldMakePersistentRequest', (_message.Message,), {
  'DESCRIPTOR' : _OLDMAKEPERSISTENTREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.OldMakePersistentRequest)
  })
_sym_db.RegisterMessage(OldMakePersistentRequest)

FederateRequest = _reflection.GeneratedProtocolMessageType('FederateRequest', (_message.Message,), {
  'DESCRIPTOR' : _FEDERATEREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.FederateRequest)
  })
_sym_db.RegisterMessage(FederateRequest)

NotifyFederationRequest = _reflection.GeneratedProtocolMessageType('NotifyFederationRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYFEDERATIONREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NotifyFederationRequest)
  })
_sym_db.RegisterMessage(NotifyFederationRequest)

UnfederateRequest = _reflection.GeneratedProtocolMessageType('UnfederateRequest', (_message.Message,), {
  'DESCRIPTOR' : _UNFEDERATEREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.UnfederateRequest)
  })
_sym_db.RegisterMessage(UnfederateRequest)

NotifyUnfederationRequest = _reflection.GeneratedProtocolMessageType('NotifyUnfederationRequest', (_message.Message,), {
  'DESCRIPTOR' : _NOTIFYUNFEDERATIONREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NotifyUnfederationRequest)
  })
_sym_db.RegisterMessage(NotifyUnfederationRequest)

ExecuteImplementationRequest = _reflection.GeneratedProtocolMessageType('ExecuteImplementationRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEIMPLEMENTATIONREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ExecuteImplementationRequest)
  })
_sym_db.RegisterMessage(ExecuteImplementationRequest)

ExecuteImplementationResponse = _reflection.GeneratedProtocolMessageType('ExecuteImplementationResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEIMPLEMENTATIONRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ExecuteImplementationResponse)
  })
_sym_db.RegisterMessage(ExecuteImplementationResponse)

NewVersionRequest = _reflection.GeneratedProtocolMessageType('NewVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWVERSIONREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NewVersionRequest)
  })
_sym_db.RegisterMessage(NewVersionRequest)

NewVersionResponse = _reflection.GeneratedProtocolMessageType('NewVersionResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWVERSIONRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NewVersionResponse)
  })
_sym_db.RegisterMessage(NewVersionResponse)

ConsolidateVersionRequest = _reflection.GeneratedProtocolMessageType('ConsolidateVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONSOLIDATEVERSIONREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ConsolidateVersionRequest)
  })
_sym_db.RegisterMessage(ConsolidateVersionRequest)

UpsertObjectsRequest = _reflection.GeneratedProtocolMessageType('UpsertObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPSERTOBJECTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.UpsertObjectsRequest)
  })
_sym_db.RegisterMessage(UpsertObjectsRequest)

NewReplicaRequest = _reflection.GeneratedProtocolMessageType('NewReplicaRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWREPLICAREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NewReplicaRequest)
  })
_sym_db.RegisterMessage(NewReplicaRequest)

NewReplicaResponse = _reflection.GeneratedProtocolMessageType('NewReplicaResponse', (_message.Message,), {
  'DESCRIPTOR' : _NEWREPLICARESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.NewReplicaResponse)
  })
_sym_db.RegisterMessage(NewReplicaResponse)

MoveObjectsRequest = _reflection.GeneratedProtocolMessageType('MoveObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _MOVEOBJECTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.MoveObjectsRequest)
  })
_sym_db.RegisterMessage(MoveObjectsRequest)

MoveObjectsResponse = _reflection.GeneratedProtocolMessageType('MoveObjectsResponse', (_message.Message,), {
  'DESCRIPTOR' : _MOVEOBJECTSRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.MoveObjectsResponse)
  })
_sym_db.RegisterMessage(MoveObjectsResponse)

RemoveObjectsRequest = _reflection.GeneratedProtocolMessageType('RemoveObjectsRequest', (_message.Message,), {
  'DESCRIPTOR' : _REMOVEOBJECTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.RemoveObjectsRequest)
  })
_sym_db.RegisterMessage(RemoveObjectsRequest)

RemoveObjectsResponse = _reflection.GeneratedProtocolMessageType('RemoveObjectsResponse', (_message.Message,), {

  'RemovedObjectsEntry' : _reflection.GeneratedProtocolMessageType('RemovedObjectsEntry', (_message.Message,), {
    'DESCRIPTOR' : _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.RemoveObjectsResponse.RemovedObjectsEntry)
    })
  ,
  'DESCRIPTOR' : _REMOVEOBJECTSRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.RemoveObjectsResponse)
  })
_sym_db.RegisterMessage(RemoveObjectsResponse)
_sym_db.RegisterMessage(RemoveObjectsResponse.RemovedObjectsEntry)

MigrateObjectsRequest = _reflection.GeneratedProtocolMessageType('MigrateObjectsRequest', (_message.Message,), {

  'DestStorageLocsEntry' : _reflection.GeneratedProtocolMessageType('DestStorageLocsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.MigrateObjectsRequest.DestStorageLocsEntry)
    })
  ,
  'DESCRIPTOR' : _MIGRATEOBJECTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.MigrateObjectsRequest)
  })
_sym_db.RegisterMessage(MigrateObjectsRequest)
_sym_db.RegisterMessage(MigrateObjectsRequest.DestStorageLocsEntry)

MigratedObjects = _reflection.GeneratedProtocolMessageType('MigratedObjects', (_message.Message,), {
  'DESCRIPTOR' : _MIGRATEDOBJECTS,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.MigratedObjects)
  })
_sym_db.RegisterMessage(MigratedObjects)

MigrateObjectsResponse = _reflection.GeneratedProtocolMessageType('MigrateObjectsResponse', (_message.Message,), {

  'MigratedObjsEntry' : _reflection.GeneratedProtocolMessageType('MigratedObjsEntry', (_message.Message,), {
    'DESCRIPTOR' : _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.MigrateObjectsResponse.MigratedObjsEntry)
    })
  ,
  'DESCRIPTOR' : _MIGRATEOBJECTSRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.MigrateObjectsResponse)
  })
_sym_db.RegisterMessage(MigrateObjectsResponse)
_sym_db.RegisterMessage(MigrateObjectsResponse.MigratedObjsEntry)

ActivateTracingRequest = _reflection.GeneratedProtocolMessageType('ActivateTracingRequest', (_message.Message,), {
  'DESCRIPTOR' : _ACTIVATETRACINGREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ActivateTracingRequest)
  })
_sym_db.RegisterMessage(ActivateTracingRequest)

CloseSessionInDSRequest = _reflection.GeneratedProtocolMessageType('CloseSessionInDSRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONINDSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.CloseSessionInDSRequest)
  })
_sym_db.RegisterMessage(CloseSessionInDSRequest)

DiskCollectRequest = _reflection.GeneratedProtocolMessageType('DiskCollectRequest', (_message.Message,), {

  'RefsToUpdateEntry' : _reflection.GeneratedProtocolMessageType('RefsToUpdateEntry', (_message.Message,), {
    'DESCRIPTOR' : _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.DiskCollectRequest.RefsToUpdateEntry)
    })
  ,
  'DESCRIPTOR' : _DISKCOLLECTREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DiskCollectRequest)
  })
_sym_db.RegisterMessage(DiskCollectRequest)
_sym_db.RegisterMessage(DiskCollectRequest.RefsToUpdateEntry)

GetClassIDFromObjectInMemoryRequest = _reflection.GeneratedProtocolMessageType('GetClassIDFromObjectInMemoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSIDFROMOBJECTINMEMORYREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetClassIDFromObjectInMemoryRequest)
  })
_sym_db.RegisterMessage(GetClassIDFromObjectInMemoryRequest)

GetClassIDFromObjectInMemoryResponse = _reflection.GeneratedProtocolMessageType('GetClassIDFromObjectInMemoryResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCLASSIDFROMOBJECTINMEMORYRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetClassIDFromObjectInMemoryResponse)
  })
_sym_db.RegisterMessage(GetClassIDFromObjectInMemoryResponse)

StoreToDBRequest = _reflection.GeneratedProtocolMessageType('StoreToDBRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORETODBREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.StoreToDBRequest)
  })
_sym_db.RegisterMessage(StoreToDBRequest)

GetFromDBRequest = _reflection.GeneratedProtocolMessageType('GetFromDBRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFROMDBREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetFromDBRequest)
  })
_sym_db.RegisterMessage(GetFromDBRequest)

GetFromDBResponse = _reflection.GeneratedProtocolMessageType('GetFromDBResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFROMDBRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetFromDBResponse)
  })
_sym_db.RegisterMessage(GetFromDBResponse)

UpdateToDBRequest = _reflection.GeneratedProtocolMessageType('UpdateToDBRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATETODBREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.UpdateToDBRequest)
  })
_sym_db.RegisterMessage(UpdateToDBRequest)

DeleteToDBRequest = _reflection.GeneratedProtocolMessageType('DeleteToDBRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETETODBREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DeleteToDBRequest)
  })
_sym_db.RegisterMessage(DeleteToDBRequest)

DeleteSetFromDBRequest = _reflection.GeneratedProtocolMessageType('DeleteSetFromDBRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESETFROMDBREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DeleteSetFromDBRequest)
  })
_sym_db.RegisterMessage(DeleteSetFromDBRequest)

UpdateRefsRequest = _reflection.GeneratedProtocolMessageType('UpdateRefsRequest', (_message.Message,), {

  'RefsToUpdateEntry' : _reflection.GeneratedProtocolMessageType('RefsToUpdateEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEREFSREQUEST_REFSTOUPDATEENTRY,
    '__module__' : 'protos.dataservice_messages_pb2'
    # @@protoc_insertion_point(class_scope:protos.dataservice.UpdateRefsRequest.RefsToUpdateEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEREFSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.UpdateRefsRequest)
  })
_sym_db.RegisterMessage(UpdateRefsRequest)
_sym_db.RegisterMessage(UpdateRefsRequest.RefsToUpdateEntry)

GetRetainedReferencesResponse = _reflection.GeneratedProtocolMessageType('GetRetainedReferencesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETRETAINEDREFERENCESRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetRetainedReferencesResponse)
  })
_sym_db.RegisterMessage(GetRetainedReferencesResponse)

SynchronizeRequest = _reflection.GeneratedProtocolMessageType('SynchronizeRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCHRONIZEREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.SynchronizeRequest)
  })
_sym_db.RegisterMessage(SynchronizeRequest)

ExistsRequest = _reflection.GeneratedProtocolMessageType('ExistsRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ExistsRequest)
  })
_sym_db.RegisterMessage(ExistsRequest)

ExistsResponse = _reflection.GeneratedProtocolMessageType('ExistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ExistsResponse)
  })
_sym_db.RegisterMessage(ExistsResponse)

ExistsInDBRequest = _reflection.GeneratedProtocolMessageType('ExistsInDBRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSINDBREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ExistsInDBRequest)
  })
_sym_db.RegisterMessage(ExistsInDBRequest)

ExistsInDBResponse = _reflection.GeneratedProtocolMessageType('ExistsInDBResponse', (_message.Message,), {
  'DESCRIPTOR' : _EXISTSINDBRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.ExistsInDBResponse)
  })
_sym_db.RegisterMessage(ExistsInDBResponse)

DetachObjectFromSessionRequest = _reflection.GeneratedProtocolMessageType('DetachObjectFromSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DETACHOBJECTFROMSESSIONREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DetachObjectFromSessionRequest)
  })
_sym_db.RegisterMessage(DetachObjectFromSessionRequest)

DeleteAliasRequest = _reflection.GeneratedProtocolMessageType('DeleteAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALIASREQUEST,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.DeleteAliasRequest)
  })
_sym_db.RegisterMessage(DeleteAliasRequest)

GetObjectGraphResponse = _reflection.GeneratedProtocolMessageType('GetObjectGraphResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTGRAPHRESPONSE,
  '__module__' : 'protos.dataservice_messages_pb2'
  # @@protoc_insertion_point(class_scope:protos.dataservice.GetObjectGraphResponse)
  })
_sym_db.RegisterMessage(GetObjectGraphResponse)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n7es.bsc.dataclay.communication.grpc.messages.dataserviceP\000'
  _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY._options = None
  _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY._serialized_options = b'8\001'
  _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY._options = None
  _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY._serialized_options = b'8\001'
  _DEPLOYCLASSESREQUEST_CLASSIDSENTRY._options = None
  _DEPLOYCLASSESREQUEST_CLASSIDSENTRY._serialized_options = b'8\001'
  _DEPLOYCLASSESREQUEST_ASPECTSENTRY._options = None
  _DEPLOYCLASSESREQUEST_ASPECTSENTRY._serialized_options = b'8\001'
  _DEPLOYCLASSESREQUEST_YAMLSENTRY._options = None
  _DEPLOYCLASSESREQUEST_YAMLSENTRY._serialized_options = b'8\001'
  _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY._options = None
  _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY._serialized_options = b'8\001'
  _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY._options = None
  _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY._serialized_options = b'8\001'
  _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY._options = None
  _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY._serialized_options = b'8\001'
  _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY._options = None
  _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY._serialized_options = b'8\001'
  _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY._options = None
  _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY._serialized_options = b'8\001'
  _UPDATEREFSREQUEST_REFSTOUPDATEENTRY._options = None
  _UPDATEREFSREQUEST_REFSTOUPDATEENTRY._serialized_options = b'8\001'
  _INITBACKENDIDREQUEST._serialized_start=87
  _INITBACKENDIDREQUEST._serialized_end=128
  _ASSOCIATEEXECUTIONENVIRONMENTREQUEST._serialized_start=130
  _ASSOCIATEEXECUTIONENVIRONMENTREQUEST._serialized_end=200
  _DEPLOYMETACLASSESREQUEST._serialized_start=203
  _DEPLOYMETACLASSESREQUEST._serialized_end=393
  _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY._serialized_start=340
  _DEPLOYMETACLASSESREQUEST_DEPLOYMENTPACKENTRY._serialized_end=393
  _DEPLOYCLASSESREQUEST._serialized_start=396
  _DEPLOYCLASSESREQUEST._serialized_end=938
  _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY._serialized_start=741
  _DEPLOYCLASSESREQUEST_CLASSESTODEPLOYENTRY._serialized_end=795
  _DEPLOYCLASSESREQUEST_CLASSIDSENTRY._serialized_start=797
  _DEPLOYCLASSESREQUEST_CLASSIDSENTRY._serialized_end=844
  _DEPLOYCLASSESREQUEST_ASPECTSENTRY._serialized_start=846
  _DEPLOYCLASSESREQUEST_ASPECTSENTRY._serialized_end=892
  _DEPLOYCLASSESREQUEST_YAMLSENTRY._serialized_start=894
  _DEPLOYCLASSESREQUEST_YAMLSENTRY._serialized_end=938
  _ENRICHCLASSREQUEST._serialized_start=940
  _ENRICHCLASSREQUEST._serialized_end=1051
  _NEWPERSISTENTINSTANCEREQUEST._serialized_start=1054
  _NEWPERSISTENTINSTANCEREQUEST._serialized_end=1350
  _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY._serialized_start=1299
  _NEWPERSISTENTINSTANCEREQUEST_IFACEBITMAPSENTRY._serialized_end=1350
  _NEWPERSISTENTINSTANCERESPONSE._serialized_start=1352
  _NEWPERSISTENTINSTANCERESPONSE._serialized_end=1448
  _STOREOBJECTSREQUEST._serialized_start=1451
  _STOREOBJECTSREQUEST._serialized_end=1590
  _GETCOPYOFOBJECTREQUEST._serialized_start=1592
  _GETCOPYOFOBJECTREQUEST._serialized_end=1672
  _GETCOPYOFOBJECTRESPONSE._serialized_start=1675
  _GETCOPYOFOBJECTRESPONSE._serialized_end=1805
  _UPDATEOBJECTREQUEST._serialized_start=1807
  _UPDATEOBJECTREQUEST._serialized_end=1934
  _GETOBJECTSREQUEST._serialized_start=1937
  _GETOBJECTSREQUEST._serialized_end=2095
  _GETOBJECTSRESPONSE._serialized_start=2098
  _GETOBJECTSRESPONSE._serialized_end=2226
  _OLDMAKEPERSISTENTREQUEST._serialized_start=2228
  _OLDMAKEPERSISTENTREQUEST._serialized_end=2334
  _FEDERATEREQUEST._serialized_start=2336
  _FEDERATEREQUEST._serialized_end=2449
  _NOTIFYFEDERATIONREQUEST._serialized_start=2451
  _NOTIFYFEDERATIONREQUEST._serialized_end=2556
  _UNFEDERATEREQUEST._serialized_start=2558
  _UNFEDERATEREQUEST._serialized_end=2673
  _NOTIFYUNFEDERATIONREQUEST._serialized_start=2675
  _NOTIFYUNFEDERATIONREQUEST._serialized_end=2740
  _EXECUTEIMPLEMENTATIONREQUEST._serialized_start=2743
  _EXECUTEIMPLEMENTATIONREQUEST._serialized_end=2897
  _EXECUTEIMPLEMENTATIONRESPONSE._serialized_start=2900
  _EXECUTEIMPLEMENTATIONRESPONSE._serialized_end=3036
  _NEWVERSIONREQUEST._serialized_start=3038
  _NEWVERSIONREQUEST._serialized_end=3117
  _NEWVERSIONRESPONSE._serialized_start=3119
  _NEWVERSIONRESPONSE._serialized_end=3204
  _CONSOLIDATEVERSIONREQUEST._serialized_start=3206
  _CONSOLIDATEVERSIONREQUEST._serialized_end=3277
  _UPSERTOBJECTSREQUEST._serialized_start=3279
  _UPSERTOBJECTSREQUEST._serialized_end=3385
  _NEWREPLICAREQUEST._serialized_start=3387
  _NEWREPLICAREQUEST._serialized_end=3485
  _NEWREPLICARESPONSE._serialized_start=3487
  _NEWREPLICARESPONSE._serialized_end=3581
  _MOVEOBJECTSREQUEST._serialized_start=3583
  _MOVEOBJECTSREQUEST._serialized_end=3678
  _MOVEOBJECTSRESPONSE._serialized_start=3680
  _MOVEOBJECTSRESPONSE._serialized_end=3770
  _REMOVEOBJECTSREQUEST._serialized_start=3772
  _REMOVEOBJECTSREQUEST._serialized_end=3884
  _REMOVEOBJECTSRESPONSE._serialized_start=3887
  _REMOVEOBJECTSRESPONSE._serialized_end=4099
  _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY._serialized_start=4046
  _REMOVEOBJECTSRESPONSE_REMOVEDOBJECTSENTRY._serialized_end=4099
  _MIGRATEOBJECTSREQUEST._serialized_start=4102
  _MIGRATEOBJECTSREQUEST._serialized_end=4306
  _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY._serialized_start=4216
  _MIGRATEOBJECTSREQUEST_DESTSTORAGELOCSENTRY._serialized_end=4306
  _MIGRATEDOBJECTS._serialized_start=4308
  _MIGRATEDOBJECTS._serialized_end=4339
  _MIGRATEOBJECTSRESPONSE._serialized_start=4342
  _MIGRATEOBJECTSRESPONSE._serialized_end=4649
  _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY._serialized_start=4561
  _MIGRATEOBJECTSRESPONSE_MIGRATEDOBJSENTRY._serialized_end=4649
  _ACTIVATETRACINGREQUEST._serialized_start=4651
  _ACTIVATETRACINGREQUEST._serialized_end=4691
  _CLOSESESSIONINDSREQUEST._serialized_start=4693
  _CLOSESESSIONINDSREQUEST._serialized_end=4737
  _DISKCOLLECTREQUEST._serialized_start=4740
  _DISKCOLLECTREQUEST._serialized_end=4952
  _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY._serialized_start=4901
  _DISKCOLLECTREQUEST_REFSTOUPDATEENTRY._serialized_end=4952
  _GETCLASSIDFROMOBJECTINMEMORYREQUEST._serialized_start=4954
  _GETCLASSIDFROMOBJECTINMEMORYREQUEST._serialized_end=5009
  _GETCLASSIDFROMOBJECTINMEMORYRESPONSE._serialized_start=5011
  _GETCLASSIDFROMOBJECTINMEMORYRESPONSE._serialized_end=5113
  _STORETODBREQUEST._serialized_start=5115
  _STORETODBREQUEST._serialized_end=5201
  _GETFROMDBREQUEST._serialized_start=5203
  _GETFROMDBREQUEST._serialized_end=5271
  _GETFROMDBRESPONSE._serialized_start=5273
  _GETFROMDBRESPONSE._serialized_end=5357
  _UPDATETODBREQUEST._serialized_start=5359
  _UPDATETODBREQUEST._serialized_end=5461
  _DELETETODBREQUEST._serialized_start=5463
  _DELETETODBREQUEST._serialized_end=5532
  _DELETESETFROMDBREQUEST._serialized_start=5534
  _DELETESETFROMDBREQUEST._serialized_end=5624
  _UPDATEREFSREQUEST._serialized_start=5627
  _UPDATEREFSREQUEST._serialized_end=5778
  _UPDATEREFSREQUEST_REFSTOUPDATEENTRY._serialized_start=4901
  _UPDATEREFSREQUEST_REFSTOUPDATEENTRY._serialized_end=4952
  _GETRETAINEDREFERENCESRESPONSE._serialized_start=5780
  _GETRETAINEDREFERENCESRESPONSE._serialized_end=5886
  _SYNCHRONIZEREQUEST._serialized_start=5889
  _SYNCHRONIZEREQUEST._serialized_end=6059
  _EXISTSREQUEST._serialized_start=6061
  _EXISTSREQUEST._serialized_end=6094
  _EXISTSRESPONSE._serialized_start=6096
  _EXISTSRESPONSE._serialized_end=6175
  _EXISTSINDBREQUEST._serialized_start=6177
  _EXISTSINDBREQUEST._serialized_end=6214
  _EXISTSINDBRESPONSE._serialized_start=6216
  _EXISTSINDBRESPONSE._serialized_end=6299
  _DETACHOBJECTFROMSESSIONREQUEST._serialized_start=6301
  _DETACHOBJECTFROMSESSIONREQUEST._serialized_end=6370
  _DELETEALIASREQUEST._serialized_start=6372
  _DELETEALIASREQUEST._serialized_end=6429
  _GETOBJECTGRAPHRESPONSE._serialized_start=6431
  _GETOBJECTGRAPHRESPONSE._serialized_end=6527
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/metadata_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from . import common_messages_pb2 as protos_dot_common__messages__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprotos/metadata_service.proto\x12\x17protos.metadata_service\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cprotos/common_messages.proto\"7\n\x11NewAccountRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"%\n\x11GetAccountRequest\x12\x10\n\x08username\x18\x01 \x01(\t\"\x14\n\x12GetAccountResponse\"M\n\x11NewSessionRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t\"!\n\x13\x43loseSessionRequest\x12\n\n\x02id\x18\x01 \x01(\t\"H\n\x11NewDatasetRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0f\n\x07\x64\x61taset\x18\x03 \x01(\t\"x\n\"GetAllExecutionEnvironmentsRequest\x12&\n\x08language\x18\x01 \x01(\x0e\x32\x14.protos.common.Langs\x12\x14\n\x0cget_external\x18\x02 \x01(\x08\x12\x14\n\x0c\x66rom_backend\x18\x03 \x01(\x08\"\xcd\x01\n#GetAllExecutionEnvironmentsResponse\x12]\n\texec_envs\x18\x01 \x03(\x0b\x32J.protos.metadata_service.GetAllExecutionEnvironmentsResponse.ExecEnvsEntry\x1aG\n\rExecEnvsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12%\n\x05value\x18\x02 \x01(\x0b\x32\x16.protos.common.Backend:\x02\x38\x01\",\n\x15GetDataclayIDResponse\x12\x13\n\x0b\x64\x61taclay_id\x18\x01 \x01(\t\"x\n\x15\x41utoRegisterEERequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\x05\x12\x0f\n\x07sl_name\x18\x04 \x01(\t\x12\"\n\x04lang\x18\x05 \x01(\x0e\x32\x14.protos.common.Langs\"]\n\x15RegisterObjectRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x30\n\tobject_md\x18\x02 \x01(\x0b\x32\x1d.protos.common.ObjectMetadata\"?\n\x16GetObjectMDByIdRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x11\n\tobject_id\x18\x02 \x01(\t\"Y\n\x19GetObjectMDByAliasRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t\"R\n\x12\x44\x65leteAliasRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nalias_name\x18\x02 \x01(\t\x12\x14\n\x0c\x64\x61taset_name\x18\x03 \x01(\t2\xa4\t\n\x0fMetadataService\x12R\n\nNewAccount\x12*.protos.metadata_service.NewAccountRequest\x1a\x16.google.protobuf.Empty\"\x00\x12g\n\nGetAccount\x12*.protos.metadata_service.GetAccountRequest\x1a+.protos.metadata_service.GetAccountResponse\"\x00\x12R\n\nNewSession\x12*.protos.metadata_service.NewSessionRequest\x1a\x16.protos.common.Session\"\x00\x12V\n\x0c\x43loseSession\x12,.protos.metadata_service.CloseSessionRequest\x1a\x16.google.protobuf.Empty\"\x00\x12R\n\nNewDataset\x12*.protos.metadata_service.NewDatasetRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x9a\x01\n\x1bGetAllExecutionEnvironments\x12;.protos.metadata_service.GetAllExecutionEnvironmentsRequest\x1a<.protos.metadata_service.GetAllExecutionEnvironmentsResponse\"\x00\x12Y\n\rGetDataclayID\x12\x16.google.protobuf.Empty\x1a..protos.metadata_service.GetDataclayIDResponse\"\x00\x12Z\n\x0e\x41utoregisterEE\x12..protos.metadata_service.AutoRegisterEERequest\x1a\x16.google.protobuf.Empty\"\x00\x12Z\n\x0eRegisterObject\x12..protos.metadata_service.RegisterObjectRequest\x1a\x16.google.protobuf.Empty\"\x00\x12\x63\n\x0fGetObjectMDById\x12/.protos.metadata_service.GetObjectMDByIdRequest\x1a\x1d.protos.common.ObjectMetadata\"\x00\x12i\n\x12GetObjectMDByAlias\x12\x32.protos.metadata_service.GetObjectMDByAliasRequest\x1a\x1d.protos.common.ObjectMetadata\"\x00\x12T\n\x0b\x44\x65leteAlias\x12+.protos.metadata_service.DeleteAliasRequest\x1a\x16.google.protobuf.Empty\"\x00\x62\x06proto3')



_NEWACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['NewAccountRequest']
_GETACCOUNTREQUEST = DESCRIPTOR.message_types_by_name['GetAccountRequest']
_GETACCOUNTRESPONSE = DESCRIPTOR.message_types_by_name['GetAccountResponse']
_NEWSESSIONREQUEST = DESCRIPTOR.message_types_by_name['NewSessionRequest']
_CLOSESESSIONREQUEST = DESCRIPTOR.message_types_by_name['CloseSessionRequest']
_NEWDATASETREQUEST = DESCRIPTOR.message_types_by_name['NewDatasetRequest']
_GETALLEXECUTIONENVIRONMENTSREQUEST = DESCRIPTOR.message_types_by_name['GetAllExecutionEnvironmentsRequest']
_GETALLEXECUTIONENVIRONMENTSRESPONSE = DESCRIPTOR.message_types_by_name['GetAllExecutionEnvironmentsResponse']
_GETALLEXECUTIONENVIRONMENTSRESPONSE_EXECENVSENTRY = _GETALLEXECUTIONENVIRONMENTSRESPONSE.nested_types_by_name['ExecEnvsEntry']
_GETDATACLAYIDRESPONSE = DESCRIPTOR.message_types_by_name['GetDataclayIDResponse']
_AUTOREGISTEREEREQUEST = DESCRIPTOR.message_types_by_name['AutoRegisterEERequest']
_REGISTEROBJECTREQUEST = DESCRIPTOR.message_types_by_name['RegisterObjectRequest']
_GETOBJECTMDBYIDREQUEST = DESCRIPTOR.message_types_by_name['GetObjectMDByIdRequest']
_GETOBJECTMDBYALIASREQUEST = DESCRIPTOR.message_types_by_name['GetObjectMDByAliasRequest']
_DELETEALIASREQUEST = DESCRIPTOR.message_types_by_name['DeleteAliasRequest']
NewAccountRequest = _reflection.GeneratedProtocolMessageType('NewAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWACCOUNTREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.NewAccountRequest)
  })
_sym_db.RegisterMessage(NewAccountRequest)

GetAccountRequest = _reflection.GeneratedProtocolMessageType('GetAccountRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetAccountRequest)
  })
_sym_db.RegisterMessage(GetAccountRequest)

GetAccountResponse = _reflection.GeneratedProtocolMessageType('GetAccountResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETACCOUNTRESPONSE,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetAccountResponse)
  })
_sym_db.RegisterMessage(GetAccountResponse)

NewSessionRequest = _reflection.GeneratedProtocolMessageType('NewSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWSESSIONREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.NewSessionRequest)
  })
_sym_db.RegisterMessage(NewSessionRequest)

CloseSessionRequest = _reflection.GeneratedProtocolMessageType('CloseSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSESESSIONREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.CloseSessionRequest)
  })
_sym_db.RegisterMessage(CloseSessionRequest)

NewDatasetRequest = _reflection.GeneratedProtocolMessageType('NewDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _NEWDATASETREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.NewDatasetRequest)
  })
_sym_db.RegisterMessage(NewDatasetRequest)

GetAllExecutionEnvironmentsRequest = _reflection.GeneratedProtocolMessageType('GetAllExecutionEnvironmentsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETALLEXECUTIONENVIRONMENTSREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetAllExecutionEnvironmentsRequest)
  })
_sym_db.RegisterMessage(GetAllExecutionEnvironmentsRequest)

GetAllExecutionEnvironmentsResponse = _reflection.GeneratedProtocolMessageType('GetAllExecutionEnvironmentsResponse', (_message.Message,), {

  'ExecEnvsEntry' : _reflection.GeneratedProtocolMessageType('ExecEnvsEntry', (_message.Message,), {
    'DESCRIPTOR' : _GETALLEXECUTIONENVIRONMENTSRESPONSE_EXECENVSENTRY,
    '__module__' : 'protos.metadata_service_pb2'
    # @@protoc_insertion_point(class_scope:protos.metadata_service.GetAllExecutionEnvironmentsResponse.ExecEnvsEntry)
    })
  ,
  'DESCRIPTOR' : _GETALLEXECUTIONENVIRONMENTSRESPONSE,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetAllExecutionEnvironmentsResponse)
  })
_sym_db.RegisterMessage(GetAllExecutionEnvironmentsResponse)
_sym_db.RegisterMessage(GetAllExecutionEnvironmentsResponse.ExecEnvsEntry)

GetDataclayIDResponse = _reflection.GeneratedProtocolMessageType('GetDataclayIDResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDATACLAYIDRESPONSE,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetDataclayIDResponse)
  })
_sym_db.RegisterMessage(GetDataclayIDResponse)

AutoRegisterEERequest = _reflection.GeneratedProtocolMessageType('AutoRegisterEERequest', (_message.Message,), {
  'DESCRIPTOR' : _AUTOREGISTEREEREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.AutoRegisterEERequest)
  })
_sym_db.RegisterMessage(AutoRegisterEERequest)

RegisterObjectRequest = _reflection.GeneratedProtocolMessageType('RegisterObjectRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTEROBJECTREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.RegisterObjectRequest)
  })
_sym_db.RegisterMessage(RegisterObjectRequest)

GetObjectMDByIdRequest = _reflection.GeneratedProtocolMessageType('GetObjectMDByIdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTMDBYIDREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetObjectMDByIdRequest)
  })
_sym_db.RegisterMessage(GetObjectMDByIdRequest)

GetObjectMDByAliasRequest = _reflection.GeneratedProtocolMessageType('GetObjectMDByAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETOBJECTMDBYALIASREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.GetObjectMDByAliasRequest)
  })
_sym_db.RegisterMessage(GetObjectMDByAliasRequest)

DeleteAliasRequest = _reflection.GeneratedProtocolMessageType('DeleteAliasRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEALIASREQUEST,
  '__module__' : 'protos.metadata_service_pb2'
  # @@protoc_insertion_point(class_scope:protos.metadata_service.DeleteAliasRequest)
  })
_sym_db.RegisterMessage(DeleteAliasRequest)

_METADATASERVICE = DESCRIPTOR.services_by_name['MetadataService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETALLEXECUTIONENVIRONMENTSRESPONSE_EXECENVSENTRY._options = None
  _GETALLEXECUTIONENVIRONMENTSRESPONSE_EXECENVSENTRY._serialized_options = b'8\001'
  _NEWACCOUNTREQUEST._serialized_start=117
  _NEWACCOUNTREQUEST._serialized_end=172
  _GETACCOUNTREQUEST._serialized_start=174
  _GETACCOUNTREQUEST._serialized_end=211
  _GETACCOUNTRESPONSE._serialized_start=213
  _GETACCOUNTRESPONSE._serialized_end=233
  _NEWSESSIONREQUEST._serialized_start=235
  _NEWSESSIONREQUEST._serialized_end=312
  _CLOSESESSIONREQUEST._serialized_start=314
  _CLOSESESSIONREQUEST._serialized_end=347
  _NEWDATASETREQUEST._serialized_start=349
  _NEWDATASETREQUEST._serialized_end=421
  _GETALLEXECUTIONENVIRONMENTSREQUEST._serialized_start=423
  _GETALLEXECUTIONENVIRONMENTSREQUEST._serialized_end=543
  _GETALLEXECUTIONENVIRONMENTSRESPONSE._serialized_start=546
  _GETALLEXECUTIONENVIRONMENTSRESPONSE._serialized_end=751
  _GETALLEXECUTIONENVIRONMENTSRESPONSE_EXECENVSENTRY._serialized_start=680
  _GETALLEXECUTIONENVIRONMENTSRESPONSE_EXECENVSENTRY._serialized_end=751
  _GETDATACLAYIDRESPONSE._serialized_start=753
  _GETDATACLAYIDRESPONSE._serialized_end=797
  _AUTOREGISTEREEREQUEST._serialized_start=799
  _AUTOREGISTEREEREQUEST._serialized_end=919
  _REGISTEROBJECTREQUEST._serialized_start=921
  _REGISTEROBJECTREQUEST._serialized_end=1014
  _GETOBJECTMDBYIDREQUEST._serialized_start=1016
  _GETOBJECTMDBYIDREQUEST._serialized_end=1079
  _GETOBJECTMDBYALIASREQUEST._serialized_start=1081
  _GETOBJECTMDBYALIASREQUEST._serialized_end=1170
  _DELETEALIASREQUEST._serialized_start=1172
  _DELETEALIASREQUEST._serialized_end=1254
  _METADATASERVICE._serialized_start=1257
  _METADATASERVICE._serialized_end=2445
# @@protoc_insertion_point(module_scope)
